PackedVec

Struct PackedVec 

pub struct PackedVec<T: ?Sized + PackedItem> { /* private fields */ }
A packed vector that stores slices of an element type in a single contiguous buffer.

This behaves somewhat like a Vec<Box<[T]>> or Vec<Vec<T>>, but allows for better memory locality and fewer allocations by storing all elements in one Vec<T::Item>.

Implementations

Source

impl<T: ?Sized + PackedItem> PackedVec<T>

pub fn new() -> Self

Creates a new empty PackedVec.

pub fn with_capacity(element_capacity: usize, buffer_capacity: usize) -> Self

Creates a new PackedVec with the specified capacities.

The element_capacity argument specifies the number of slices that can be stored without reallocating the offsets vector. The buffer_capacity argument specifies the cumulative length of slices that can be stored without reallocating the data vector.

pub fn clear(&mut self)

Clears the vector, removing all elements.

pub fn from_slice<U: AsRef<T>>(slices: &[U]) -> Self

Creates a new PackedVec from a slice of element slices, pre-allocating the required capacity.

pub fn reserve(&mut self, additional: usize)

Reserves capacity for at least additional more elements to be inserted.

pub fn shrink_to_fit(&mut self)

Shrinks the capacity of the vector as much as possible.

pub fn push(&mut self, slice: &T)

Appends an item to the back of the collection.

pub fn get(&self, index: usize) -> Option<&T>

Returns the slice at the given index, or None if out of bounds.

pub unsafe fn get_unchecked(&self, index: usize) -> &T

Returns a reference to the slice at the given index without bounds checking.

Safety

The index must be less than self.len().

pub fn len(&self) -> usize

Returns the number of slices in the vector.

pub fn buffer_len(&self) -> usize

Returns the cumulative length of all slices in the vector in bytes.

pub fn is_empty(&self) -> bool

Returns true if the vector contains no slices.

Binary searches this sorted vector for a given element.

If the value is found then Result::Ok is returned, containing the index of the matching element. If there are multiple matches, then any one of the matches could be returned.

If the value is not found then Result::Err is returned, containing the index where a matching element could be inserted while maintaining sorted order.

pub fn binary_search_by<'a, F>(&'a self, f: F) -> Result<usize, usize>
where F: FnMut(&'a T) -> Ordering,

Binary searches this sorted vector for a given element.

If the value is found then Result::Ok is returned, containing the index of the matching element. If there are multiple matches, then any one of the matches could be returned.

If the value is not found then Result::Err is returned, containing the index where a matching element could be inserted while maintaining sorted order.

pub fn first(&self) -> Option<&T>

Returns the first element of the vector, or None if it is empty.

pub fn last(&self) -> Option<&T>

Returns the last element of the vector, or None if it is empty.

pub fn iter(&self) -> Iter<'_, T>

Returns an iterator over the slices.

pub fn drain(&mut self) -> Drain<'_, T>

Returns a draining iterator that removes all elements and yields them.

pub fn range<R: RangeBounds<usize>>(&self, range: R) -> Iter<'_, T>

Returns an iterator over a sub-range of slices in the vector.

The bounds must be usize bounds (representing indices). If bounds are outside the vector length or inverted, they will be clipped.